==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/TermJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * @author kimchy (Shay Banon)
 */
public class TermJsonQueryBuilder extends BaseJsonQueryBuilder {

    private final String name;

    private final Object value;

    private float boost = -1;

    public TermJsonQueryBuilder(String name, String value) {
        this(name, (Object) value);
    }

    public TermJsonQueryBuilder(String name, int value) {
        this(name, (Object) value);
    }

    public TermJsonQueryBuilder(String name, long value) {
        this(name, (Object) value);
    }

    public TermJsonQueryBuilder(String name, float value) {
        this(name, (Object) value);
    }

    public TermJsonQueryBuilder(String name, double value) {
        this(name, (Object) value);
    }

    private TermJsonQueryBuilder(String name, Object value) {
        this.name = name;
        this.value = value;
    }

    public TermJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override public void doJson(JsonBuilder builder) throws IOException {
        builder.startObject(TermJsonQueryParser.NAME);
        if (boost == -1) {
            builder.field(name, value);
        } else {
            builder.startObject(name);
            builder.field("value", value);
            builder.field("boost", boost);
            builder.endObject();
        }
        builder.endObject();
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/TermJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * A Query that matches documents containing a term.
 *
 * @author kimchy (shay.banon)
 */
public class TermJsonQueryBuilder extends BaseJsonQueryBuilder {

    private final String name;

    private final Object value;

    private float boost = -1;

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    public TermJsonQueryBuilder(String name, String value) {
        this(name, (Object) value);
    }

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    public TermJsonQueryBuilder(String name, int value) {
        this(name, (Object) value);
    }

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    public TermJsonQueryBuilder(String name, long value) {
        this(name, (Object) value);
    }

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    public TermJsonQueryBuilder(String name, float value) {
        this(name, (Object) value);
    }

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    public TermJsonQueryBuilder(String name, double value) {
        this(name, (Object) value);
    }

    /**
     * Constructs a new term query.
     *
     * @param name  The name of the field
     * @param value The value of the term
     */
    private TermJsonQueryBuilder(String name, Object value) {
        this.name = name;
        this.value = value;
    }

    /**
     * Sets the boost for this query.  Documents matching this query will (in addition to the normal
     * weightings) have their score multiplied by the boost provided.
     */
    public TermJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override public void doJson(JsonBuilder builder, Params params) throws IOException {
        builder.startObject(TermJsonQueryParser.NAME);
        if (boost == -1) {
            builder.field(name, value);
        } else {
            builder.startObject(name);
            builder.field("value", value);
            builder.field("boost", boost);
            builder.endObject();
        }
        builder.endObject();
    }
}
